@@ -24,27 +24,25 @@ import importlib
 import time
 import threading
 import requests
+import logging
+
+logging.basicConfig(level=logging.INFO)
 
 class Cakework(cakework_pb2_grpc.CakeworkServicer):
     def __init__(self, user_activity, local=False):
         self.user_activity = user_activity
         self.local = local
         if self.local:
-            self.frontend_url = "http://host.docker.internal:8080"
+            self.frontend_url = "http://localhost:8080"
         else:
             self.frontend_url = "https://cakework-frontend.fly.dev"
 
     def RunActivity(self, request, context):
-        print("local mode is: " + str(self.local))
-        print("frontend url: " + self.frontend_url)
-        print("got request")
-        print(request)
-        print("after printing request")
         # update to in progress
         response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": request.userId, "app": request.app, "requestId": request.requestId, "status": "IN_PROGRESS"})
-        print("updated status to IN_PROGRESS") # this may be a lie
         # TODO check the response
         parameters = json.loads(request.parameters)
+        # parameters = json.loads(request.parameters) # instead of passing a dict (parameters), pass a variable number of parameters 
         task = threading.Thread(target=self.background, args=[request.userId, request.app, request.requestId, parameters])
         task.daemon = True # Q: does returning kill the task?
         task.start()
@@ -53,26 +51,24 @@ class Cakework(cakework_pb2_grpc.CakeworkServicer):
 
     # note: we need to get the request id in here as well
     def background(self, user_id, app, request_id, parameters):
-
-        # print("starting background task with parameters: " + str(parameters))
+        res = ""
+        # logging.info("starting background task with parameters: " + str(parameters))
         try:
-            res = self.user_activity(**parameters)
-            print("finished task")
+            logging.info("Starting request " + request_id)
+            res = self.user_activity(*parameters)
             # TODO call the frontend api to update the status and result
             
-
+            logging.info("Finished request " + request_id)
             response = requests.patch(f"{self.frontend_url}/update-result", json={"userId": user_id, "app": app, "requestId": request_id, "result": json.dumps(res)})
-            print("updated result")
-            print(response)
             # TODO check the response
             response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": user_id, "app": app, "requestId": request_id, "status": "SUCCEEDED"})
-            print("updated status")
-            print(response)
 
         except Exception as e:
-            print("got an exception: ")
-            print(e)
-            response = requests.patch(f"{self.frontend_url}/update-result", json={"userId": user_id, "app": app, "requestId": request_id, "status": "FAILED"})
+            logging.exception("Error occurred while running task", exc_info=True)
+            # logging.info(e)
+            response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": user_id, "app": app, "requestId": request_id, "status": "FAILED"})
+            # TODO: handle case if updating the status in the db failed; then user may keep polling forever
+            return cakework_pb2.Reply(result=None)
 
         # Q: who are we returning to here? instead of returning, we can just write this to the database. or emit a message and have the poller be in charge of writing to db
         return cakework_pb2.Reply(result=json.dumps(res))
@@ -83,7 +79,7 @@ def serve():
     cakework_pb2_grpc.add_CakeworkServicer_to_server(Cakework(), server)
     server.add_insecure_port('[::]:' + port)
     server.start()
-    print("Server started, listening on " + port)
+    logging.info("Server started, listening on " + port)
     server.wait_for_termination()
 
 if __name__ == '__main__':
@@ -101,5 +97,5 @@ class ActivityServer:
         cakework_pb2_grpc.add_CakeworkServicer_to_server(Cakework(self.user_activity, self.local), self.server)
         self.server.add_insecure_port('[::]:' + port)
         self.server.start()
-        print("Server started, listening on " + port)
-        self.server.wait_for_termination()
+        logging.info("Server started, listening on " + port)
+        self.server.wait_for_termination()
\ No newline at end of file
